@@ -13,7 +13,7 @@
 # limitations under the License.
 
 # Modified by NSN
-#  Copyright 2010-2012 Nokia Siemens Networks Oyj
+#  Copyright 2010-2012 Nokia Solutions and Networks
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -49,7 +49,7 @@ ATEXIT_LOCK = threading.RLock()
 
 class TestRunner(object):
 
-    def __init__(self, chief):
+    def __init__(self, project):
         self._output_dir = None
         self._process = None
         self._server = None
@@ -58,7 +58,7 @@ class TestRunner(object):
         self._pid_to_kill = None
         self._results = TestExecutionResults()
         self.port = None
-        self._chief = chief
+        self._project = project
         self.profiles = {}
 
     def enable(self, result_handler):
@@ -121,7 +121,7 @@ class TestRunner(object):
                                                                    testname))
 
     def _get_test_controller(self, longname, testname = None):
-        ret = self._chief.find_controller_by_longname(longname, testname)
+        ret = self._project.find_controller_by_longname(longname, testname)
         return ret
 
     def clear_server(self):
@@ -178,7 +178,8 @@ class TestRunner(object):
         command.extend(["--argumentfile", argfile])
         command.extend(["--listener", self._get_listener_to_cmd()])
         command.append(self._get_suite_source_for_command())
-        self._write_argfile(argfile, self._create_standard_args(command, profile, pythonpath, monitor_width, names_to_run))
+        self._write_argfile(argfile, self._create_standard_args(
+            command, profile, pythonpath, monitor_width, names_to_run))
         return command
 
     @staticmethod
@@ -204,18 +205,18 @@ class TestRunner(object):
 
     def _get_suite_source_for_command(self):
         cur = os.path.abspath(os.path.curdir)
-        source = os.path.abspath(self._chief.suite.source)
+        source = os.path.abspath(self._project.suite.source)
         if not utils.is_same_drive(cur, source):
             return source
-        return os.path.abspath(self._chief.suite.source)
+        return os.path.abspath(self._project.suite.source)
 
-    def _create_standard_args(self, command, profile, pythonpath, monitor_width, names_to_run):
+    def _create_standard_args(
+            self, command, profile, pythonpath, monitor_width, names_to_run):
         standard_args = []
         standard_args.extend(profile.get_custom_args())
         self._add_tmp_outputdir_if_not_given_by_user(command, standard_args)
-        self._add_pythonpath_if_in_settings_and_not_given_by_user(command,
-                                                                  standard_args,
-                                                                  pythonpath)
+        self._add_pythonpath_if_in_settings_and_not_given_by_user(
+            command, standard_args, pythonpath)
         standard_args.extend(["--monitorcolors", "off"])
         standard_args.extend(["--monitorwidth", monitor_width])
         for suite, test in names_to_run:
@@ -228,7 +229,7 @@ class TestRunner(object):
 
     @staticmethod
     def _add_pythonpath_if_in_settings_and_not_given_by_user(
-        command, standard_args, pythonpath):
+            command, standard_args, pythonpath):
         if '--pythonpath' in command:
             return
         if '-P' in command:
@@ -243,8 +244,11 @@ class TestRunner(object):
         f.write("\n".join(args))
         f.close()
 
-    def get_output_and_errors(self):
-        return self._process.get_output(), self._process.get_errors()
+    def get_output_and_errors(self, profile):
+        stdout, stderr, returncode = self._process.get_output(), \
+            self._process.get_errors(), self._process.get_returncode()
+        error, log_message = profile.format_error(stderr, returncode)
+        return stdout, error, log_message
 
     def is_running(self):
         return self._process and self._process.is_alive()
@@ -301,6 +305,9 @@ class Process(object):
     def get_errors(self):
         return self._error_stream.pop()
 
+    def get_returncode(self):
+        return self._process.returncode
+
     def is_alive(self):
         return self._process.poll() is None
 
