@@ -1,4 +1,4 @@
-#  Copyright 2008-2012 Nokia Siemens Networks Oyj
+#  Copyright 2008-2015 Nokia Solutions and Networks
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -13,25 +13,20 @@
 #  limitations under the License.
 
 import os
+import sys
 import re
 import operator
 import tempfile
 from itertools import chain
 
-from robot.errors import DataError
-from robot.parsing.model import ResourceFile
-from robot.parsing.settings import Library, Resource, Variables
-from robot.utils.normalizing import normalize
-from robot.variables import Variables as RobotVariables
+from robotide import robotapi, utils
 from robotide.namespace import variablefetcher
 from robotide.namespace.cache import LibraryCache, ExpiringCache
 from robotide.namespace.resourcefactory import ResourceFactory
-from robotide.spec.iteminfo import (TestCaseUserKeywordInfo,
-                                    ResourceUserKeywordInfo,
-                                    VariableInfo, _UserKeywordInfo,
-    ArgumentInfo)
-from robotide.robotapi import NormalizedDict, is_var
+from robotide.spec.iteminfo import TestCaseUserKeywordInfo,\
+    ResourceUserKeywordInfo, VariableInfo, _UserKeywordInfo, ArgumentInfo
 from robotide.namespace.embeddedargs import EmbeddedArgsHandler
+from robotide.publish import PUBLISHER, RideSettingsChanged
 
 
 class Namespace(object):
@@ -39,16 +34,33 @@ class Namespace(object):
     def __init__(self, settings):
         self._settings = settings
         self._library_manager = None
-        self._init_caches()
         self._content_assist_hooks = []
         self._update_listeners = set()
+        self._init_caches()
+        self._set_pythonpath()
+        PUBLISHER.subscribe(self._setting_changed, RideSettingsChanged)
 
     def _init_caches(self):
-        self._lib_cache = LibraryCache(self._settings, self.update, self._library_manager)
+        self._lib_cache = LibraryCache(
+            self._settings, self.update, self._library_manager)
         self._resource_factory = ResourceFactory(self._settings)
         self._retriever = DatafileRetriever(self._lib_cache, self._resource_factory)
         self._context_factory = _RetrieverContextFactory()
 
+    def _set_pythonpath(self):
+        values = self._settings.get('pythonpath', [])
+        for path in values:
+            if path not in sys.path:
+                sys.path.insert(0, path.replace('/', os.sep))
+
+    def _setting_changed(self, message):
+        section, setting = message.keys
+        if section == '' and setting == 'pythonpath':
+            for p in set(message.old).difference(message.new):
+                if p in sys.path:
+                    sys.path.remove(p)
+            self._set_pythonpath()
+
     def set_library_manager(self, library_manager):
         self._library_manager = library_manager
         self._lib_cache.set_library_manager(library_manager)
@@ -116,33 +128,37 @@ class Namespace(object):
         return start == ''
 
     def _looks_like_variable(self, start):
-        return (len(start) == 1 and start.startswith('$') or start.startswith('@')) \
-            or (len(start) >= 2 and start.startswith('${') or start.startswith('@{'))
+        return (len(start) == 1 and start.startswith('$') or
+                start.startswith('@')) \
+            or (len(start) >= 2 and start.startswith('${') or
+                start.startswith('@{'))
 
     def _variable_suggestions(self, controller, start, ctx):
         datafile = controller.datafile
-        start_normalized = normalize(start)
+        start_normalized = utils.normalize(start)
         self._add_kw_arg_vars(controller, ctx.vars)
-        vars = self._retriever.get_variables_from(datafile, ctx)
-        return (v for v in vars
-                if normalize(v.name).startswith(start_normalized))
+        variables = self._retriever.get_variables_from(datafile, ctx)
+        return (v for v in variables
+                if utils.normalize(v.name).startswith(start_normalized))
 
-    def _add_kw_arg_vars(self, controller, vars):
+    def _add_kw_arg_vars(self, controller, variables):
         for name, value in controller.get_local_variables().iteritems():
-            vars.set_argument(name, value)
+            variables.set_argument(name, value)
 
     def _keyword_suggestions(self, datafile, start, ctx):
-        start_normalized = normalize(start)
-        return (sug for sug in chain(self._get_default_keywords(),
-                                           self._retriever.get_keywords_from(datafile, ctx))
-                      if sug.name_begins_with(start_normalized) or
-                         sug.longname_begins_with(start_normalized))
+        start_normalized = utils.normalize(start)
+        return (sug for sug in chain(
+            self._get_default_keywords(),
+            self._retriever.get_keywords_from(datafile, ctx))
+                if sug.name_begins_with(start_normalized) or
+                sug.longname_begins_with(start_normalized))
 
     def get_resources(self, datafile):
         return self._retriever.get_resources_from(datafile)
 
     def get_resource(self, path, directory='', report_status=True):
-        return self._resource_factory.get_resource(directory, path, report_status=report_status)
+        return self._resource_factory.get_resource(
+            directory, path, report_status=report_status)
 
     def find_resource_with_import(self, imp):
         ctx = self._context_factory.ctx_for_datafile(imp.parent.parent)
@@ -163,10 +179,12 @@ class Namespace(object):
         return kw if kw and kw.is_library_keyword() else None
 
     def is_library_import_ok(self, datafile, imp):
-        return self._retriever.is_library_import_ok(datafile, imp, self._context_factory.ctx_for_datafile(datafile))
+        return self._retriever.is_library_import_ok(
+            datafile, imp, self._context_factory.ctx_for_datafile(datafile))
 
     def is_variables_import_ok(self, datafile, imp):
-        return self._retriever.is_variables_import_ok(datafile, imp, self._context_factory.ctx_for_datafile(datafile))
+        return self._retriever.is_variables_import_ok(
+            datafile, imp, self._context_factory.ctx_for_datafile(datafile))
 
     def find_keyword(self, datafile, kw_name):
         if not kw_name:
@@ -258,7 +276,7 @@ class _VariableStash(object):
     ARGUMENT_SOURCE = object()
 
     def __init__(self):
-        self._vars = RobotVariables()
+        self._vars = robotapi.RobotVariables()
         self._sources = {}
         for k, v in self.global_variables.iteritems():
             self.set(k, v, 'built-in')
@@ -273,7 +291,7 @@ class _VariableStash(object):
     def replace_variables(self, value):
         try:
             return self._vars.replace_scalar(value)
-        except DataError:
+        except robotapi.DataError:
             return self._vars.replace_string(value, ignore_errors=True)
 
     def set_from_variable_table(self, variable_table):
@@ -282,10 +300,12 @@ class _VariableStash(object):
                 if not self._vars.has_key(variable.name):
                     _, value = self._vars._get_var_table_name_and_value(
                         variable.name,
-                        variable.value)
+                        variable.value,
+                        variable.report_invalid_syntax
+                    )
                     self.set(variable.name, value, variable_table.source)
-            except DataError:
-                if is_var(variable.name):
+            except robotapi.DataError:
+                if robotapi.is_var(variable.name):
                     self.set(variable.name, '', variable_table.source)
 
     def set_from_file(self, varfile_path, args):
@@ -345,12 +365,12 @@ class DatafileRetriever(object):
         return self._import_vars(ctx, datafile, imp)
 
     def _get_datafile_keywords(self, datafile):
-        if isinstance(datafile, ResourceFile):
+        if isinstance(datafile, robotapi.ResourceFile):
             return [ResourceUserKeywordInfo(kw) for kw in datafile.keywords]
         return [TestCaseUserKeywordInfo(kw) for kw in datafile.keywords]
 
     def _get_imported_library_keywords(self, datafile, ctx):
-        return self._collect_kws_from_imports(datafile, Library,
+        return self._collect_kws_from_imports(datafile, robotapi.Library,
                                               self._lib_kw_getter, ctx)
 
     def _collect_kws_from_imports(self, datafile, instance_type, getter, ctx):
@@ -377,7 +397,7 @@ class DatafileRetriever(object):
                 if isinstance(imp, instance_type)]
 
     def _get_imported_resource_keywords(self, datafile, ctx):
-        return self._collect_kws_from_imports(datafile, Resource,
+        return self._collect_kws_from_imports(datafile, robotapi.Resource,
                                               self._res_kw_recursive_getter, ctx)
 
     def _res_kw_recursive_getter(self, imp, ctx):
@@ -387,7 +407,7 @@ class DatafileRetriever(object):
             return kws
         ctx.parsed.add(res)
         ctx.set_variables_from_datafile_variable_table(res)
-        for child in self._collect_import_of_type(res, Resource):
+        for child in self._collect_import_of_type(res, robotapi.Resource):
             kws.extend(self._res_kw_recursive_getter(child, ctx))
         kws.extend(self._get_imported_library_keywords(res, ctx))
         return [ResourceUserKeywordInfo(kw) for kw in res.keywords] + kws
@@ -402,7 +422,7 @@ class DatafileRetriever(object):
         return ctx
 
     def _collect_vars_from_variable_files(self, datafile, ctx):
-        for imp in self._collect_import_of_type(datafile, Variables):
+        for imp in self._collect_import_of_type(datafile, robotapi.Variables):
             self._import_vars(ctx, datafile, imp)
 
     def _import_vars(self, ctx, datafile, imp):
@@ -412,7 +432,7 @@ class DatafileRetriever(object):
         try:
             ctx.vars.set_from_file(varfile_path, args)
             return True
-        except DataError:
+        except robotapi.DataError:
             return False # TODO: log somewhere
 
     def _var_collector(self, res, ctx, items):
@@ -441,7 +461,7 @@ class DatafileRetriever(object):
     def _collect_each_res_import(self, datafile, ctx, collector):
         items = set()
         ctx.set_variables_from_datafile_variable_table(datafile)
-        for imp in self._collect_import_of_type(datafile, Resource):
+        for imp in self._collect_import_of_type(datafile, robotapi.Resource):
             res = self._resource_factory.get_resource_from_import(imp, ctx)
             if res and res not in ctx.parsed:
                 ctx.parsed.add(res)
@@ -472,7 +492,7 @@ class _Keywords(object):
     regexp = re.compile("\s*(given|when|then|and)\s*(.*)", re.IGNORECASE)
 
     def __init__(self, keywords):
-        self.keywords = NormalizedDict(ignore=['_'])
+        self.keywords = robotapi.NormalizedDict(ignore=['_'])
         self.embedded_keywords = {}
         self._add_keywords(keywords)
 
@@ -511,4 +531,3 @@ class _Keywords(object):
     def _get_bdd_name(self, kw_name):
         match = self.regexp.match(kw_name)
         return match.group(2) if match else None
-
