@@ -1,4 +1,4 @@
-#  Copyright 2008-2012 Nokia Siemens Networks Oyj
+#  Copyright 2008-2015 Nokia Solutions and Networks
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -13,7 +13,7 @@
 #  limitations under the License.
 
 from button import ButtonWithHandler
-from dialog import Dialog
+from dialog import Dialog, HtmlDialog
 from font import Font
 from htmlwindow import HtmlWindow
 from images import ImageList, ImageProvider
